@@ -1,3 +1,4 @@
+import csv
 import getpass
 import importlib
 import json
@@ -20,6 +21,7 @@ class Encoding(Enum):
     JSON = 2
     BINARY = 3
     CRYPTOGRAPHY = 4
+    CSV = 5
 
 
 class Storage(Enum):
@@ -33,15 +35,15 @@ class Storage(Enum):
 class save:
     """Save data, supports multiple systems.
 
-    Supported Systems: [File, FTP]
+    Supported Systems: [File, FTP, GOOGLE]
     Partial Supported: []
-    Planning Support for: [Google]
+    Planning Support for: []
     """
 
     def __init__(self) -> None:
         """Loading the class, storing data such as enum, modules, settings"""
         self.encoding: Encoding = Enum(
-            "Encoding", ["NONE", "JSON", "BINARY", "CRYPTOGRAPHY"]
+            "Encoding", ["NONE", "JSON", "BINARY", "CRYPTOGRAPHY", "CSV"]
         )
         self.storage: Storage = Enum("Storage", ["NORMAL", "FTP", "GOOGLE", "OTHER"])
         self.saveModules = {}
@@ -220,6 +222,32 @@ class save:
 
                 rBytes = True
 
+            if code.value == 5:
+                if not decode:
+                    with open("csv.temp", "w", encoding="utf-8") as f:
+                        csv_writer = csv.DictWriter(f, data.get("header"))
+                        csv_writer.writeheader()
+                        csv_writer.writerows(data.get("rows"))
+
+                    with open("csv.temp", "r", encoding="utf-8") as f:
+                        result = f.read()
+
+                    os.remove("csv.temp")
+                else:
+                    with open("csv.temp", "w", encoding="utf-8") as f:
+                        f.write(data)
+
+                    with open("csv.temp", "r", encoding="utf-8") as f:
+                        csv_reader = csv.DictReader(f)
+                        data = {"header": csv_reader.fieldnames}
+                        rows = []
+                        for item in csv_reader:
+                            rows.append(item)
+                        data["row"] = rows
+                        result = data
+
+                    os.remove("csv.temp")
+
         return result, rBytes
 
     def __GetFileInformation(
